

### <a name="manual"></a> vSpace block

Inserts a vertical space in the document flow.

| Key       |      Description      | Default |
|:----------|:--------------------- |:----------|
| type      |  vspace                 |  
| height    |  (optional) height of the space in cm        | 12pt |

Example:
```YAML
- type     : vspace
  height   : 5.6
```

Back to [Documentation](../../../README.md#block_basic)
